<template>
	<div class="bbsl-common-page">
		<div class="bbsl-table-search">
			<el-form v-model="queryParam" label-width="auto">
				<el-row :gutter="10">
					<el-col :span="7"><el-form-item label="操作时间">
							<el-date-picker v-model="querys[0].value" type="datetimerange" style="width:100%"
								popper-class="dataTime-style" value-format="yyyy-MM-dd HH:mm:ss" range-separator="至"
								start-placeholder="开始日期" end-placeholder="结束日期">
							</el-date-picker>
						</el-form-item></el-col>
					<el-col :span="4"><el-button type="primary" icon="el-icon-search"
							@click="handleSearch">搜索</el-button>
						<el-button icon="el-icon-refresh" @click="handleReset">重置</el-button></el-col>
				</el-row>
			</el-form>
		</div>
		<div class="bbsl-table-content" ref="contentPanel">
			<div class="bbsl-btn-content" ref="btnPanel"></div>
			<el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
				:style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
				:header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
				@selection-change="handleSelectionChange">
				<el-table-column fixed type="index" width="55" label="序号"></el-table-column>
				<el-table-column prop="deviceCode" label="设备标识" show-overflow-tooltip></el-table-column>
				<el-table-column prop="deviceName" label="设备名称" show-overflow-tooltip>
					<template slot-scope="scope">
						<span class="active" @click="toDialog(scope.row.deviceName)">{{ scope.row.deviceName }}</span>
					</template>
				</el-table-column>
				<el-table-column prop="createBy" label="操作人" show-overflow-tooltip></el-table-column>
				<el-table-column prop="collTime" label="操作时间" show-overflow-tooltip></el-table-column>
				<!-- <el-table-column
          
          prop="createTime"
          label="入库时间"
          show-overflow-tooltip
        ></el-table-column> -->
				<el-table-column prop="actionName" label="动作标识" show-overflow-tooltip></el-table-column>
				<el-table-column prop="statusName" label="操作状态" show-overflow-tooltip></el-table-column>
			</el-table>
			<el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
				@size-change="handleSizeChange" @current-change="handleCurrentChange"
				:current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
				:page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="total"></el-pagination>
		</div>
		<RealTimeMonitorDialog ref="RealTimeMonitorDialog"></RealTimeMonitorDialog>
	</div>
</template>

<script>
import {
	TableMixin
} from '@/mixins/tableMixin'
import riotBarricade from '@/api/device/riotBarricade.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import RealTimeMonitorDialog from '@/components/detailsDialog/RealTimeMonitorDialog.vue'
export default {
	name: 'RealTimeMonitor',
	components: {
		RealTimeMonitorDialog
	},
	mixins: [TableMixin],
	data() {
		return {
			querys: [{
				group: 'main',
				operation: 'BETWEEN',
				parentGroup: '',
				property: 'b.coll_time_',
				relation: 'AND',
				value: ''
			}],
			sorter: [{
				direction: 'DESC',
				property: 'createTime'
			}],
			actionList: [], //动作标识字典
			statusList: [] //成功状态字典
		}
	},
	created() {
		this.actionList = dictUtils.getDictItemsFromCache('dzbs')
		this.statusList = dictUtils.getDictItemsFromCache('cgzt')
	},
	mounted() { },
	methods: {
		handleUpdate(row) {
			console.log(row);
		},
		toDialog(name) {
			this.$refs.RealTimeMonitorDialog.add(name)
		},
		clearQuerys() {
			this.querys[0].value = ''
		},
		loadData(page) {
			if (page) {
				this.queryParam.pageBean.page = page
			}
			this.loading = true
			this.tableData = []
			this.queryParam.querys = []
			this.queryParam = Object.assign(this.queryParam, {
				sorter: this.sorter
			})
			if (this.querys[0].value) {
				this.queryParam.querys.push(this.querys[0])
			}
			riotBarricade.loadQuery(this.queryParam, res => {
				// console.log(res, 'ppppppp')
				this.tableData = res.rows
				this.total = res.total
				this.$set(this.tableData)
				this.loading = false
				this.tableData.forEach(item => {
					this.actionList.forEach(val => {
						if (item.action && item.action == val.value) {
							item['actionName'] = val.name
						}
					})
					this.statusList.forEach(val => {
						if (item.status && item.status == val.value) {
							item['statusName'] = val.name
						}
					})
				})
			})
		}
	}
}
</script>
<style lang="scss" scoped>
.type-tag {
	margin: 0 2px;
}

.active {
	color: #3399ff;
	cursor: pointer;
}
</style>
<style lang="scss">
.dataTime-style {
	.el-time-spinner__item {
		height: auto !important;
		line-height: inherit;
	}

	.el-scrollbar__wrap {
		overflow: scroll !important;
	}
}
</style>
